@@ -217,7 +217,6 @@ shm_show_hw_info(SynapticsSHM *synshm)
 	printf("    This is normal if you are running linux kernel 2.6.\n");
 	printf("    Check the kernel log for touchpad hardware information.\n");
     }
-    printf("Driver version: %d\n", (PACKAGE_VERSION_MAJOR*10000+PACKAGE_VERSION_MINOR*100+PACKAGE_VERSION_PATCHLEVEL));
 }
 
 static void
@@ -445,7 +444,7 @@ dp_init()
 
 unwind:
     XFree(v);
-    if (error)
+    if (error && dpy)
     {
 	XCloseDisplay(dpy);
 	dpy = NULL;
@@ -508,7 +507,9 @@ dp_get_device(Display *dpy)
 unwind:
     XFree(properties);
     XFreeDeviceList(info);
-    if (error && dev)
+    if (!dev)
+        fprintf(stderr, "Unable to find a synaptics device.\n");
+    else if (error && dev)
     {
 	XCloseDevice(dpy, dev);
 	dev = NULL;
